/*
 * File:   LivestockAddDialog.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */

 
package gui.context;

import gui.Popup;
import sim.*;
import sim.livestock.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;


/** Dialog box to define livestock properties on herd creation */
public class LivestockAddDialog extends JDialog implements ActionListener, ItemListener, KeyListener{

	private Simulation sim;
	private JFrame parent;
	private JTextField qtyValue;
	private JTextField nameValue;
	private JButton doButton;
	private JButton cancelButton;
	private Choice typeList;
	private Choice stateList;
	
	private int currentType = Animal.SHEEP;
	private int currentState = Animal.STATE_EARLY;
	private int quantity = 0;
	private LivestockGroup group = null;
	
	public LivestockAddDialog(JFrame parent){ super(parent, true); this.parent = parent; }
	
	public LivestockGroup show(Simulation sim){
		this.sim = sim;
		setTitle("Add Group");
		setDefaultCloseOperation(DISPOSE_ON_CLOSE);
		setResizable(false);
		
		Container pane = getContentPane();
		SpringLayout layout = new SpringLayout();
		pane.setLayout(layout);
				
		JLabel nameLabel = new JLabel("Name:"); pane.add(nameLabel);
		nameValue = new JTextField("Untitled", 10); pane.add(nameValue);
		JLabel typeLabel = new JLabel("Type:"); pane.add(typeLabel);
		typeList = new Choice(); pane.add(typeList);
		typeList.setFont(new Font("SansSerif", Font.PLAIN, 10));
		//typeList.setSize(150,25);
		typeList.add("Sheep");
		typeList.add("Cows");
		typeList.add("Horses");
		typeList.addItemListener(this);
		JLabel stateLabel = new JLabel("Physological State:"); pane.add(stateLabel);
		stateList = new Choice(); pane.add(stateList);
		stateList.setFont(new Font("SansSerif", Font.PLAIN, 10));
		//typeList.setSize(150,25);
		stateList.add("Early Growth");
		stateList.add("Late Growth");
		stateList.add("Pregnant");
		stateList.add("Lactating");
		stateList.add("Adult");
		stateList.addItemListener(this);
		JLabel qtyLabel = new JLabel("Size:"); pane.add(qtyLabel);
		qtyValue = new JTextField("", 4); pane.add(qtyValue); qtyValue.addKeyListener(this);
		doButton = new JButton("Place");
		pane.add(doButton); doButton.addActionListener(this);
		cancelButton = new JButton("Cancel");
		pane.add(cancelButton); cancelButton.addActionListener(this);
		
		layout.putConstraint(SpringLayout.NORTH, nameLabel, 10, SpringLayout.NORTH, pane);
		layout.putConstraint(SpringLayout.WEST,  nameLabel, 10, SpringLayout.WEST, pane);
		layout.putConstraint(SpringLayout.EAST,  pane, 10, SpringLayout.EAST, nameValue);
		layout.putConstraint(SpringLayout.SOUTH, pane, 10, SpringLayout.SOUTH, cancelButton);
		
		layout.putConstraint(SpringLayout.NORTH, nameValue, -2, SpringLayout.NORTH, nameLabel);
		layout.putConstraint(SpringLayout.WEST,  nameValue, 10, SpringLayout.EAST, nameLabel);
		layout.putConstraint(SpringLayout.NORTH, typeLabel, 20, SpringLayout.SOUTH, nameLabel);
		layout.putConstraint(SpringLayout.WEST,  typeLabel, 0, SpringLayout.WEST, nameLabel);
		layout.putConstraint(SpringLayout.NORTH, typeList, -5, SpringLayout.NORTH, typeLabel);
		layout.putConstraint(SpringLayout.WEST,  typeList,  0, SpringLayout.WEST, nameValue);
		layout.putConstraint(SpringLayout.NORTH, stateLabel, 20, SpringLayout.SOUTH, typeLabel);
		layout.putConstraint(SpringLayout.WEST,  stateLabel, 0,  SpringLayout.WEST,  nameLabel);
		layout.putConstraint(SpringLayout.NORTH, stateList, -5,  SpringLayout.NORTH, stateLabel);
		layout.putConstraint(SpringLayout.WEST,  stateList,  0,  SpringLayout.WEST,  nameValue);
		layout.putConstraint(SpringLayout.NORTH, qtyLabel, 20, SpringLayout.SOUTH, stateLabel);
		layout.putConstraint(SpringLayout.WEST,  qtyLabel, 0, SpringLayout.WEST, typeLabel);
		layout.putConstraint(SpringLayout.NORTH, qtyValue, -2, SpringLayout.NORTH, qtyLabel);
		layout.putConstraint(SpringLayout.WEST,  qtyValue,  0, SpringLayout.WEST, nameValue);
		layout.putConstraint(SpringLayout.NORTH, cancelButton, 20, SpringLayout.SOUTH, qtyLabel);
		layout.putConstraint(SpringLayout.EAST,  cancelButton, 0, SpringLayout.EAST, nameValue);
		layout.putConstraint(SpringLayout.NORTH, doButton, 0, SpringLayout.NORTH, cancelButton);
		layout.putConstraint(SpringLayout.EAST,  doButton, -10, SpringLayout.WEST, cancelButton);

		setLocationRelativeTo(parent);
		pack();
		
		show();
		
		return group;
	}
	
	public void actionPerformed(ActionEvent e){
		if(e.getSource() == doButton){
			checkText();
			if(quantity == 0){ Popup.inform("An animal group must contain at least one animal."); }
			else{
				group = new LivestockGroup(sim, nameValue.getText(), currentType, currentState, quantity);
				dispose();
			}
		}
		if(e.getSource() == cancelButton){ dispose(); }
	}
	
	public void itemStateChanged(ItemEvent e) {
		if(e.getSource() == typeList){
			String type = (String)e.getItem();
			if(type.equals("Sheep"))  currentType = Animal.SHEEP;
			if(type.equals("Cows"))   currentType = Animal.COW;
			if(type.equals("Horses")) currentType = Animal.HORSE;	
		}else if(e.getSource() == stateList){
			String state = (String)e.getItem();
			if(state.equals("Early Growth")) currentType = Animal.STATE_EARLY;
			if(state.equals("Late Growth"))  currentType = Animal.STATE_LATE;
			if(state.equals("Pregnant"))     currentType = Animal.STATE_PREGNANT;	
			if(state.equals("Lactating"))    currentType = Animal.STATE_LACTATING;	
			if(state.equals("Adult"))        currentType = Animal.STATE_ADULT;
		}
	}


	public void keyPressed(KeyEvent e){ checkText(); }
	public void keyReleased(KeyEvent e){ checkText(); }
	public void keyTyped(KeyEvent e){ checkText(); }
 
	public void checkText(){
		String text = qtyValue.getText();
		if(text == null || text.equals("")){ quantity = 0; }
		
		else{
			try{
				int n = Integer.parseInt(text);
				quantity = n;
			}catch(NumberFormatException ex){ quantity = 0; }
		}
		if(quantity == 0) qtyValue.setText("");
		else qtyValue.setText(""+quantity);
	}
}
