/*
 * File:   LivestockContextPanel.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */

 
package gui.context;

import gui.icon.*;
import sim.Simulation;
import sim.livestock.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.io.*;
import java.awt.Color;
import java.awt.Container;
import javax.swing.SpringLayout;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JButton;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;


/** The context panel for adding, removing and moving livestock groups */
public class LivestockContextPanel extends ContextPanel{

	JButton addGroup;
	JButton placeGroup;
	JButton removeGroup;

	public LivestockContextPanel(Simulation sim){ super(sim); }
	
	public void generate(){
	
		// The default context button listner
		ButtonListner buttonListner = new ButtonListner();

		addGroup    = new JButton(new PlusIcon()); addGroup.setMargin(new Insets(2,0,2,0)); add(addGroup);    addGroup.addActionListener(buttonListner);
		placeGroup  = new JButton("Move"); placeGroup.setMargin(new Insets(0,3,0,3)); add(placeGroup); placeGroup.addActionListener(buttonListner);
		removeGroup = new JButton(new MinusIcon()); removeGroup.setMargin(new Insets(2,0,2,0)); add(removeGroup); removeGroup.addActionListener(buttonListner);

		layout.putConstraint(SpringLayout.NORTH, addGroup,    12, SpringLayout.NORTH, this);
		layout.putConstraint(SpringLayout.NORTH, placeGroup,  12, SpringLayout.NORTH, this);
		layout.putConstraint(SpringLayout.NORTH, removeGroup, 12, SpringLayout.NORTH, this);

		layout.putConstraint(SpringLayout.EAST, addGroup,    0, SpringLayout.WEST, placeGroup);
		layout.putConstraint(SpringLayout.WEST, placeGroup,  (int)(getPreferredSize().getWidth()/2-20), SpringLayout.WEST, this);
		layout.putConstraint(SpringLayout.WEST, removeGroup, 0, SpringLayout.EAST, placeGroup);

		enableButtons();
	}
	
	public void enableButtons(){
		addGroup.setEnabled(true);
		placeGroup.setEnabled(sim.hasLivestock());
		removeGroup.setEnabled(sim.hasLivestock());
	}
	
	public void disableButtons(){
		addGroup.setEnabled(false);
		placeGroup.setEnabled(false);
		removeGroup.setEnabled(false);
	}
	
	
	private class ButtonListner implements ActionListener{
		public void actionPerformed(ActionEvent e) {
			if(e.getSource() == addGroup) sim.setMode(Simulation.MODE_LIVESTOCK_ADD);
			else if(e.getSource() == placeGroup) sim.setMode(Simulation.MODE_LIVESTOCK_PLACE);
			else if(e.getSource() == removeGroup) sim.setMode(Simulation.MODE_LIVESTOCK_REMOVE);
		}
	}
}
