/*
 * File:   PastureContextPanel.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */

 
package gui.context;

import gui.icon.*;
import sim.Simulation;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.io.*;
import java.awt.Color;
import java.awt.Container;
import javax.swing.SpringLayout;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JButton;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;


/** The context panel for adding/removing fields, gates and water */
public class PastureContextPanel extends ContextPanel{

	JButton addField;
	JButton removeField;
	JButton addGate;
	JButton removeGate;
	JButton addWater;
	JButton removeWater;

	public PastureContextPanel(Simulation sim){ super(sim); }
	
	public void generate(){
	
		// The default context button listner
		ButtonListner buttonListner = new ButtonListner();
		
		JLabel fieldLabel = new JLabel("Field"); add(fieldLabel);
		addField =    new JButton(new PlusIcon()); addField.setMargin(new Insets(1,0,1,0)); add(addField);    addField.addActionListener(buttonListner);
		removeField = new JButton(new MinusIcon()); removeField.setMargin(new Insets(1,0,1,0)); add(removeField); removeField.addActionListener(buttonListner);
		JLabel gateLabel = new JLabel("Gate"); add(gateLabel);
		addGate  =    new JButton(new PlusIcon());  addGate.setMargin(new Insets(1,0,1,0)); add(addGate);     addGate.addActionListener(buttonListner);
		removeGate  = new JButton(new MinusIcon()); removeGate.setMargin(new Insets(1,0,1,0)); add(removeGate);  removeGate.addActionListener(buttonListner);
		JLabel waterLabel = new JLabel("Water"); add(waterLabel);
		addWater  =    new JButton(new PlusIcon());  addWater.setMargin(new Insets(1,0,1,0)); add(addWater);     addWater.addActionListener(buttonListner);
		removeWater  = new JButton(new MinusIcon()); removeWater.setMargin(new Insets(1,0,1,0)); add(removeWater);  removeWater.addActionListener(buttonListner);

		layout.putConstraint(SpringLayout.NORTH, fieldLabel,  0, SpringLayout.NORTH, this);
		layout.putConstraint(SpringLayout.NORTH, gateLabel,   0, SpringLayout.NORTH, this);
		layout.putConstraint(SpringLayout.NORTH, waterLabel,  0, SpringLayout.NORTH, this);
		
		layout.putConstraint(SpringLayout.NORTH, addField,    3, SpringLayout.SOUTH, fieldLabel);
		layout.putConstraint(SpringLayout.NORTH, removeField, 3, SpringLayout.SOUTH, fieldLabel);
		layout.putConstraint(SpringLayout.NORTH, addGate,     3, SpringLayout.SOUTH, gateLabel);
		layout.putConstraint(SpringLayout.NORTH, removeGate,  3, SpringLayout.SOUTH, gateLabel);
		layout.putConstraint(SpringLayout.NORTH, addWater,    3, SpringLayout.SOUTH, waterLabel);
		layout.putConstraint(SpringLayout.NORTH, removeWater, 3, SpringLayout.SOUTH, waterLabel);
	
		
		layout.putConstraint(SpringLayout.WEST, fieldLabel,  0, SpringLayout.WEST, addField);
		layout.putConstraint(SpringLayout.WEST, gateLabel,   0, SpringLayout.WEST, addGate);
		layout.putConstraint(SpringLayout.WEST, waterLabel,  0, SpringLayout.WEST, addWater);
		
		layout.putConstraint(SpringLayout.EAST, addField,    -3, SpringLayout.WEST, removeField);
		layout.putConstraint(SpringLayout.EAST, removeField,-20, SpringLayout.WEST, addGate);
		layout.putConstraint(SpringLayout.EAST, addGate, -(int)(getPreferredSize().getWidth()/2)-2, SpringLayout.EAST, this);
		layout.putConstraint(SpringLayout.WEST, removeGate,   3, SpringLayout.EAST, addGate);
		layout.putConstraint(SpringLayout.WEST, addWater,    20, SpringLayout.EAST, removeGate);
		layout.putConstraint(SpringLayout.WEST, removeWater,  3, SpringLayout.EAST, addWater);
	}
	
	public void enableButtons(){
		addField.setEnabled(true);
		removeField.setEnabled(sim.hasFields());
		addGate.setEnabled(sim.hasFields());
		removeGate.setEnabled(sim.hasGates());
		addWater.setEnabled(true);
		removeWater.setEnabled(sim.hasWater());
	}
	
	public void disableButtons(){
		addField.setEnabled(false);
		removeField.setEnabled(false);
		addGate.setEnabled(false);
		removeGate.setEnabled(false);
		addWater.setEnabled(false);
		removeWater.setEnabled(false);
	}
	
	
	private class ButtonListner implements ActionListener{
		public void actionPerformed(ActionEvent e) {
			     if(e.getSource() == addField){    sim.setMode(Simulation.MODE_PASTURE_ADD_FIELD); }
			else if(e.getSource() == removeField){ sim.setMode(Simulation.MODE_PASTURE_REMOVE_FIELD); }
			else if(e.getSource() == addGate){     sim.setMode(Simulation.MODE_PASTURE_ADD_GATE); }
			else if(e.getSource() == removeGate){  sim.setMode(Simulation.MODE_PASTURE_REMOVE_GATE); }
			else if(e.getSource() == addWater){    sim.setMode(Simulation.MODE_PASTURE_ADD_WATER); }
			else if(e.getSource() == removeWater){ sim.setMode(Simulation.MODE_PASTURE_REMOVE_WATER); }
		}
	}
}
