/*
 * File:   PastureGraphWindow.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   04-03-05
 */
 
 package gui.graph;
 
import gui.*;
import gui.icon.PlotIcon;
import sim.Simulation;
import sim.livestock.*;
import main.PastureSim;

import java.awt.*;
import java.awt.Color;
import java.awt.Container;
import java.awt.event.*;
import java.awt.image.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.io.*;
import javax.swing.*;
import javax.swing.SpringLayout;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JButton;

/** Graphs pasture state */
public class PastureGraphWindow extends GraphWindow{

	public static final Color LAI_COLOUR  = Color.YELLOW;
	public static final Color DM_COLOUR   = Color.GREEN;
	public static final Color AW_COLOUR   = Color.BLUE;
	public static final Color OV_COLOUR   = Color.RED;
	
	public PastureGraphWindow(UserInterface ui, Simulation sim){
		super(ui, sim, "Pasture State");
	}
	
	
	/** Generate the gui */
	public void generate(){
		plots = new JCheckBox[4];
		plots[0] = new JCheckBox("LAI (Leaf Area)", true); plots[0].setIcon(new PlotIcon(LAI_COLOUR, plots[0])); plots[0].setPreferredSize(new Dimension(150, 25)); plots[0].addActionListener(this);
		plots[1] = new JCheckBox("DM (Dry Mass)",   true); plots[1].setIcon(new PlotIcon(DM_COLOUR,  plots[1])); plots[1].setPreferredSize(new Dimension(150, 25)); plots[1].addActionListener(this);
		plots[2] = new JCheckBox("Soil Moisture",   true); plots[2].setIcon(new PlotIcon(AW_COLOUR,  plots[2])); plots[2].setPreferredSize(new Dimension(150, 25)); plots[2].addActionListener(this);
		plots[3] = new JCheckBox("Bare Soil",       true); plots[3].setIcon(new PlotIcon(OV_COLOUR,  plots[3])); plots[3].setPreferredSize(new Dimension(150, 25)); plots[3].addActionListener(this);
		super.generate();
	 }
	
	
	/** Draws the graph data */
	public void drawGraph(Graphics g){
//System.out.println("1");
	
		if(sim.pastureGraphData == null) return;
//System.out.println("2");
		if(plots[0].isSelected()){ g.setColor(LAI_COLOUR); plotDays(sim.pastureGraphData[0], g); }
		if(plots[1].isSelected()){ g.setColor(DM_COLOUR);  plotDays(sim.pastureGraphData[1], g); }
		if(plots[2].isSelected()){ g.setColor(AW_COLOUR);  plotDays(sim.pastureGraphData[2], g); }
		if(plots[3].isSelected()){ g.setColor(OV_COLOUR);  plotDays(sim.pastureGraphData[3], g); }
	}

}
