/*
 * File:   ActionPanel.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */

 
package gui.view;

import sim.*;
import java.awt.*;
import java.awt.geom.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.io.*;
import java.util.*;


/** The action panel is the main window for viewing and manipulating all
  * simulation objects. Sub classes of this carry out tasks for each mode */
public class ActionPanel extends JPanel implements MouseListener, MouseMotionListener{

	protected Simulation sim;
	protected int clicks;
	protected int mouseX;
	protected int mouseY;
	private int oldX;
	private int oldY;
	private boolean dragging = false;
	

	public ActionPanel(Simulation sim){
		this.sim = sim;
		setBackground(Color.black);
		setBorder(BorderFactory.createLoweredBevelBorder());
		addMouseListener(this); 
       		addMouseMotionListener(this);
		
		Dimension size;
		if(sim != null){
			clicks = 0;
			size = new Dimension(sim.getPastureSize().width, sim.getPastureSize().height);
		}else{ size = new Dimension(gui.UserInterface.INIT_WIDTH, gui.UserInterface.INIT_HEIGHT); } 
		
		setPreferredSize(size);
		if(sim != null) sim.setActionPanel(this);
	}

	public void setSimulation(Simulation sim){
		this.sim = sim;
		setPreferredSize(new Dimension(sim.getPastureSize().width, sim.getPastureSize().height));
		sim.setActionPanel(this);
	}
	
	public void paintComponent(Graphics g){ super.paintComponent(g); }
	
	
	public final void mouseClicked(MouseEvent e){
		if(e.getButton() == MouseEvent.BUTTON1){
			clicks++;
			if(clicks > 2){ return; }
			if(clicks == 2){ mouseDoubleClicked(e); return;	}
			mouseSingleClicked(e);
		}
	}

	public void mouseMoved(MouseEvent e){
		clicks = 0;
		mouseX = e.getX();
		mouseY = e.getY();
	}
	
	public void mouseSingleClicked(MouseEvent e){}
	public void mouseDoubleClicked(MouseEvent e){}
	public final void mouseDragged(MouseEvent e){
		if(dragging){
			sim.pan(e.getX() - oldX, e.getY() - oldY);
			oldX = e.getX(); oldY = e.getY(); 
			repaint();
		}
	}
	public void mouseEntered (MouseEvent e){}
	public void mouseExited  (MouseEvent e){}
	public final void mousePressed (MouseEvent e){
		if(e.getButton() == MouseEvent.BUTTON3){
			dragging = true;
			oldX = e.getX(); oldY = e.getY(); 
		}
	}
	public final void mouseReleased(MouseEvent e){
		if(e.getButton() == MouseEvent.BUTTON3){ dragging = false; }
	}
}
