/*
 * File:   GateAddActionPanel.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */

 
 
package gui.view;

import sim.*;
import sim.pasture.*;
import utils.GateGeometry;

import java.awt.*;
import java.awt.geom.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.io.*;
import java.util.*;


/** The action panel for adding gates */
public class GateAddActionPanel extends ActionPanel{

	private GateGeometry geom;
	private FieldGate closestGate;
	
	public GateAddActionPanel(Simulation sim){
		super(sim);
		geom = sim.getGateGeometry();
		closestGate = null;
	}
	
	public void paintComponent(Graphics g){
		super.paintComponent(g);
		sim.drawPasture(g);
		if(closestGate != null) closestGate.drawActive(g);
	}
	
	public void mouseMoved(MouseEvent e){
		super.mouseMoved(e);
		Point2D.Double s = sim.scaledMousePos(mouseX, mouseY);
		closestGate = geom.findClosestGate(s);
		repaint();
	}
	public void mouseSingleClicked(MouseEvent e){
		if(closestGate != null && !geom.doesGateOverlap(closestGate)){
			sim.addGate(closestGate);
			sim.setMode(Simulation.MODE_PASTURE);
		}
	}
	public void mouseDoubleClicked(MouseEvent e){
		sim.setMode(Simulation.MODE_PASTURE);
	}
	public void mouseEntered (MouseEvent e){}
	public void mouseExited  (MouseEvent e){}
}
