/*
 * File:   PastureActionPanel.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */

 
 
package gui.view;

import sim.*;
import sim.pasture.*;
import utils.GateGeometry;

import java.awt.*;
import java.awt.geom.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.io.*;
import java.util.*;


/** The default action panel for pasture mode
  * (allows the opening and closing of gates) */
public class PastureActionPanel extends ActionPanel{

	private FieldGate existingGate;
	private GateGeometry geom;
	
	public PastureActionPanel(Simulation sim){
		super(sim);
		geom = sim.getGateGeometry();
		existingGate = null;
	}
	
	public void paintComponent(Graphics g){
		super.paintComponent(g);
		sim.drawPasture(g);
		if(existingGate != null) existingGate.drawActive(g);
	}
	
	public void mouseMoved(MouseEvent e){
		super.mouseMoved(e);
		Point2D.Double s = sim.scaledMousePos(mouseX, mouseY);
		FieldGate newGate = geom.findExistingGate(s);
		if(newGate != null){
			if(newGate != existingGate){
				if(existingGate != null) existingGate.unsetDrawToggle();
				newGate.setDrawToggle();
				existingGate = newGate;
			}
		}
		repaint();
	}
	public void mouseSingleClicked(MouseEvent e){
		if(existingGate != null){
			existingGate.toggle();
			repaint();
		}
	}
	
	public void notifyExit(){
		if(existingGate != null) existingGate.unsetDrawToggle();		
	}
	
	public void mouseDoubleClicked(MouseEvent e){}
	public void mouseEntered (MouseEvent e){}
	public void mouseExited  (MouseEvent e){}
}
