/*
 * File:   InitConfig.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */

 
package main;

import sim.Simulation;
import java.io.*;


/** This file is intended to store all initial pasture configuration.
  * It also handles the saving of the user specific configuration
  * There are actually other constants which can be played around with
  * in some other class files. See Sheep.java, Animal,java, GrassModel.java,
  * State.java, PastureState.java and possibly others... */
public class InitConfig{
 
 		
	public static final int speed = 0;
	public static final int zoom = 1;
	public static final int mode = Simulation.MODE_SIMULATE;
	public static final boolean drawAriel = true;
	public static final boolean drawFields = true;
	public static final boolean drawLivestock = true;
	public static final boolean drawDeadstock = false;
	public static final boolean drawWaterPaths = false;

	public float pastureArea; // This is the area that was chosen by the user
	
	private String dir; // This is the last simulation directory
	                    // and is  the only thing that is saved at the moment

		
	public InitConfig(){
		readConfig();
		pastureArea = 0;
	}
	
	public String getDir(){ return dir; }
	public void setDir(String dir){
		if(dir != null && !dir.equals("")){
			this.dir = dir;
			writeConfig();
		}
	}
	
	private void writeConfig(){
		try {
			FileOutputStream output = new FileOutputStream(".PastureSim");
			ObjectOutputStream objOut = new ObjectOutputStream(output);
			objOut.writeObject(dir);
			objOut.close();
		}catch(Exception e){ System.err.println("Couldn't write config file"); } //Return false if exception
	}
	

	private void readConfig(){
		try {
			FileInputStream input = new FileInputStream(".PastureSim");
			ObjectInputStream objIn = new ObjectInputStream(input);
			dir = (String)objIn.readObject();
			objIn.close();
		}catch(Exception e){ System.err.println("Couldn't read config file"); }
	}

}
