/*
 * File:   FrozenState.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */


package sim;

import sim.pasture.*;
import sim.livestock.*;
import gui.*;
import utils.*;

import java.awt.*;
import java.awt.image.*;
import java.io.*;
import java.util.*;
import javax.swing.JOptionPane;


/** Represents the simulation state 'frozen in time'. It saves a 
  * live SimulationState object to a dormant state onbject which 
  * can be viewed in the history browser, but cannot be activated
  * unless 'thawed' back to a SimulationState object. */
public final class FrozenState extends State implements Serializable{

	
	/** Create a live simulation state from a frozen one */
	public SimulationState thaw(Simulation sim){
		this.sim = sim;
		ownedGates = new LinkedList();
		return new SimulationState(sim, fields, gates, water, animals, pState, totalTime);
	}
	
	/** Create a frozen simulation state from a live one */
	public FrozenState(	Simulation sim,
				LinkedList fields,
				LinkedList gates,
				LinkedList water,
	                   	LinkedList animals,
				PastureState pState,
				long totalTime){
		this.sim = sim;
		this.fields = fields;
		this.gates = gates;
		this.water = water;
		this.animals = animals;
		this.pState = pState;
		this.totalTime = totalTime;
	}
	
	public void initialise(Simulation sim){
		pState.loadImage(sim);
		super.initialise(sim);
	}
	
	/*
			this.sim = sim;
		this.gates = new LinkedList();
		this.fields = new LinkedList();
		this.animals = new LinkedList();

		// Clone pState here
		// clone pos here
		Dimension d = sim.getPastureSize();
		this.pos = new Animal[d.width][d.height];
		this.pState = (PastureState)pState.clone();
				
		for(Iterator i = gates.iterator(); i.hasNext();){
			this.gates.add(((FieldGate)i.next()).clone());
		}
		for(Iterator i = fields.iterator(); i.hasNext();){
			this.fields.add(((FieldBounds)i.next()).clone(this.gates));
		}
		for(Iterator i = animals.iterator(); i.hasNext();){
			this.animals.add(((LivestockGroup)i.next()).clone(this.pState, this.pos));
		}
		this.totalTime = totalTime;
*/
				
/*
	private void writeObject(java.io.ObjectOutputStream out) throws IOException{
		out.writeObject(gates);
		out.writeObject(fields);
		pState.setImageFile(sim.genHistoryFile());
		out.writeObject(pState);
		out.writeObject(animals);
		out.writeLong(totalTime);
	}
	
	public FrozenState(java.io.ObjectInputStream in, Simulation sim) throws IOException, ClassNotFoundException{
		this.sim = sim;
		Dimension d = sim.getPastureSize();
		this.pos = new Animal[d.width][d.height];
		gates = (LinkedList)in.readObject();
		fields = (LinkedList)in.readObject();
		for(Iterator i = gates.iterator(); i.hasNext();){
			FieldGate g = (FieldGate)i.next();
			g.setSimulation(sim);
			for(Iterator j = fields.iterator(); i.hasNext();){
				FieldBounds f = (FieldBounds)j.next();
				f.setSimulation(sim);
				f.notifyGateArrival(g);	
			}	
		}
		pState = (PastureState)in.readObject();
		animals = (LinkedList)in.readObject();
		for(Iterator i = animals.iterator(); i.hasNext();){
			LivestockGroup l = (LivestockGroup)i.next();
			l.setData(sim, pos, pState);
		}
		totalTime = in.readLong();
	}
*/
/*
	// Returns wheather we own this area
	public boolean ownsArea(Point p, int size){ return super.ownsArea(p, size); }
	// Returns any connected fields containing this point over an open gate
	public AnimalContainer findOpenNeighbours(Point p){ return super.findOpenNeighbours(p); }
*/

	private void writeObject(java.io.ObjectOutputStream out) throws IOException{
		out.writeObject(fields);
		out.writeObject(gates);
		out.writeObject(water);
		out.writeObject(animals);
		out.writeObject(pState);
		out.writeLong(totalTime);
	}
	private void readObject(java.io.ObjectInputStream in) throws IOException, ClassNotFoundException{
		fields = (LinkedList)in.readObject();
		gates = (LinkedList)in.readObject();
		water = (LinkedList)in.readObject();
		animals = (LinkedList)in.readObject();
		pState = (PastureState)in.readObject();
		totalTime = in.readLong();
	}	
	
	public String toString(){ return "sim.FrozenState ["+pState+"]"; }

}

