/*
 * File:   DijkstraEdge.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   07-03-05
 */

package utils;

import sim.*;
import sim.pasture.*;
import java.awt.*;

/** Represents an edge with a weight for the Dijkstra's Algorithm.
  * The gates are edges, the fields are the vertices. */
public class DijkstraEdge implements Comparable{

	private static int count = 0;
	public int id = count++;

	public FieldGate gate;       // The gate representing the edge
	public double weight;        // The cost of reaching this gate
	public AnimalContainer next; // The next animal container this gate leads to



	public DijkstraEdge(FieldGate gate, double weight, AnimalContainer last){
		this.gate = gate;
		this.weight = weight;
		this.next = gate.neighbour(last);
	}


	/** Compares edges by weights, guarantees total ordering */
	public int compareTo(Object o){
		if(o instanceof DijkstraEdge){
			if(weight == ((DijkstraEdge)o).weight)
				return id - ((DijkstraEdge)o).id;
			if(weight > ((DijkstraEdge)o).weight)
				return 1;
		}
		return -1;
	}

}
