/*
 * File:   FieldGeometry.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */


package utils;

import gui.*;
import sim.*;
import sim.pasture.*;
import java.io.*;
import java.util.*;
import javax.swing.JOptionPane;
import java.awt.*;
import java.awt.geom.*;


/** Performs all the maths to do with the field boundaries */
public class FieldGeometry implements Serializable{
	
	public LinkedList fields;
	public Simulation sim;
	
	public FieldGeometry(LinkedList fields, Simulation sim){
		this.fields = fields;
		this.sim = sim;
	}

	public boolean overlapPointsFields(Polygon p){
		if(p == null) return false;
		for(Iterator i = fields.iterator(); i.hasNext();){
			if(((FieldBounds)i.next()).overlapPoints(p)){ return true;}
		}
		
		return false;
	}
	public boolean potentialOverlapFields(Polygon p){
		if(p == null) return false;
		for(Iterator i = fields.iterator(); i.hasNext();){
			if(((FieldBounds)i.next()).potentialOverlap(p)){ return true;}
		}
		return false;
	}
	public boolean overlapFields(Polygon p){
		if(p == null) return false;
		for(Iterator i = fields.iterator(); i.hasNext();){
			if(((FieldBounds)i.next()).overlap(p)){ return true;}
		}
		return false;
	}
	
	public Point findFieldVertex(Point2D.Double pt){
		Point closestP = new Point((int)(pt.x), (int)(pt.y));
		double smallestDistance = sim.SNAP_RADIUS;
		for(Iterator i = fields.iterator(); i.hasNext();){
			Point p = ((FieldBounds)i.next()).getCloseVertex(pt);
			if(p != null){
				double dist = Point2D.distance(closestP.x, closestP.y, pt.x, pt.y); 
				if(dist < smallestDistance){
					//System.out.println("Smallun found!");
					smallestDistance = dist;
					closestP = p;
				}
			}
		}
		return closestP;
	}
	
	// Returns the animal container which the point fully contains
	public AnimalContainer findContainingField(Point2D.Double p){
		for(Iterator i = fields.iterator(); i.hasNext();){
			FieldBounds f = (FieldBounds)i.next();
			if(f.holds(p)) return f;
		}
		return sim.state;
	}
	
	
	// Returns the animal container which contains the point.
	// it will will also return vertices of the polygon (which technically aren't contained)
	public FieldBounds findContainingFieldDraw(Point2D.Double p){
		for(Iterator i = fields.iterator(); i.hasNext();){
			FieldBounds f = (FieldBounds)i.next();
			if(f.contains(p)) return f;
		}
		return null;
	}
	
	public AnimalContainer findContainingField(Point p, int s){
		boolean withinFields = false;
		for(Iterator i = fields.iterator(); i.hasNext();){
			FieldBounds f = (FieldBounds)i.next();
			if(f.contains(p.x, p.y, s, s)) return f;
			if(f.contains(p.x,   p.y)
			 ||f.contains(p.x+s, p.y)
			 ||f.contains(p.x,   p.y+s)
			 ||f.contains(p.x+s, p.y+s)) withinFields = true;
		}
		// This means that the point is not on any borders
		// and outside of any field bounds
		if(!withinFields) return sim.state;
		return null;
	}
	
	
	/** Returns true if point p has a containing field */
	public boolean hasContainingField(Point2D.Double p){
		for(Iterator i = fields.iterator(); i.hasNext();){
			FieldBounds f = (FieldBounds)i.next();
//if(f.holds(p) != f.contains(p)) System.out.println("Cheese");
			if(f.holds(p)) return true;
		}
//System.out.println("Point "+p+" has no containing field");
		return false;
	}
	
	/** Returns true if any vertex of the square has a containing field */
	public boolean hasContainingField(Point2D.Double p, int s){
		for(Iterator i = fields.iterator(); i.hasNext();){
			FieldBounds f = (FieldBounds)i.next();
			if(f.contains(p.x,   p.y)
			 ||f.contains(p.x+s, p.y)
			 ||f.contains(p.x,   p.y+s)
			 ||f.contains(p.x+s, p.y+s)) return true;
		}
		return false;
	}
	
	/** Returns true if the line intersects any of the fences */
	public boolean intersectsFields(Point p1, Point p2){
		for(Iterator i = fields.iterator(); i.hasNext();){
			FieldBounds f = (FieldBounds)i.next();
			if(f.intersects(p1, p2)) return true;
		}
		return false;
	}
	
	
	/** Get all fields which own the gate */
/*	public LinkedList getFieldsForGate(FieldGate g){
		LinkedList owningFields = new LinkedList();
		for(Iterator i = fields.iterator(); i.hasNext();){
			FieldBounds f = (FieldBounds)i.next();
			if(f.ownsGate(g)) owningFields.add(g);
		}
		return owningFields;
	}
*/	
	/*public boolean containsFields(int x, int y){
		for(Iterator i = fields.iterator(); i.hasNext();){
			if(((FieldBounds)i.next()).contains(x, y)) return true;
		}
		return false;
	}	
	*/
	
	//private void writeObject(java.io.ObjectOutputStream out) throws IOException{}
	//private void readObject(java.io.ObjectInputStream in) throws IOException, ClassNotFoundException{}

}
