/*
 * File:   GateGeometry.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */


package utils;

import gui.*;
import sim.*;
import sim.pasture.*;
import java.io.*;
import java.util.*;
import javax.swing.JOptionPane;
import java.awt.*;
import java.awt.geom.*;


/** Performs all caluclations associated with the gates */
public class GateGeometry{
	
	public LinkedList fields;
	public LinkedList gates;
	public Simulation sim;
	
	public GateGeometry(LinkedList fields, LinkedList gates, Simulation sim){
		this.fields = fields;
		this.gates = gates;
		this.sim = sim;
	}

	// Finds the closest point that you could place a gate 
	public FieldGate findClosestGate(Point2D.Double pt){
		Point p1 = null; Point p2 = null; // Closest fence so far
		double d = Double.MAX_VALUE; // Smallest Distance
		boolean found = false;
		// Search for the closest fence
		for(Iterator i = fields.iterator(); i.hasNext();){
			Point p1_ = new Point(0,0); Point p2_ = new Point(0,0); // Closest fence for this field
			double d_ = ((FieldBounds)i.next()).getClosestFence(pt.x, pt.y, p1_, p2_); // Smallest dist for that field
			if(d_ < d){
				found = true;
				d = d_;
				p1 = p1_; p2 = p2_;
			}
		}
		if(!found) return null; // This should never hapen if a fence exists
	
		Vector2D v = new Vector2D(p1.x, p1.y, p2.x, p2.y);
		Vector2D vp = v.perp();
		FieldGate g = new FieldGate(vp.project(pt, d), v, sim);
		if(g.insideLine(p1.x, p1.y, p2.x, p2.y)) return g;  // If gate fits onto line segment then return		
		return null;
	}
	
	// Finds the closest existing gate to the point
	public FieldGate findExistingGate(Point2D.Double pt){
		FieldGate closest = null;
		double d = Double.MAX_VALUE; // Smallest Distance
		// Search for the closest fence
		for(Iterator i = gates.iterator(); i.hasNext();){
			FieldGate current = (FieldGate)i.next();
			double d_ = current.distance(pt.x,pt.y);
			if(d_ < d){ d = d_; closest = current; }
		}
		return closest;
	}
	
	public boolean doesGateOverlap(FieldGate g){
		for(Iterator i = gates.iterator(); i.hasNext();){
			if(g.overlap((FieldGate)i.next())) return true;
		}
		return false;
	}

}
