/*
 * File:   Vector2D.java
 * Author: Conrad Rider
 * Email:  c.rider@eviltree.co.uk
 * Date:   22-02-05
 */


package utils;

import java.awt.*;
import java.awt.geom.*;
import java.io.*;
import java.util.Random;


/** Class for doing vector algebra (essential for all geometric data)*/
public class Vector2D implements Cloneable, Serializable{

	public static final Vector2D i = new Vector2D(1,0);
	public static final Vector2D j = new Vector2D(0,1);
	
	public static Random rand = new Random();
	
	public double x;
	public double y;
	
	
	/** Create a random vector */
	public Vector2D(){
		this.x = Math.random() - 0.5;
		this.y = Math.random() - 0.5;
	}
	
	public Object clone(){ return new Vector2D(x, y); }
	public Vector2D(double x, double y){ this.x = x; this.y = y; }
	public Vector2D(Point2D.Double p1, Point2D.Double p2){ this(p1.x, p1.y, p2.x, p2.y); }
	public Vector2D(double x1, double y1, double x2, double y2){
		this.x = x2 - x1;
		this.y = y2 - y1;
	}
	
	public boolean equals(Vector2D v){ return (x==v.x) && (y==v.y); }
	public boolean isZeroVector(){ return x == 0.0 && y == 0.0; }
	
	public Vector2D add(Vector2D v){ return new Vector2D(x+v.x, y+v.y); }
	public Vector2D sub(Vector2D v){ return new Vector2D(x-v.x, y-v.y); }
	public Vector2D scale(int m){ return new Vector2D(x*m, y*m); }
	public Vector2D negate(){ return new Vector2D(-x, -y); }
	public Vector2D perp(){ return new Vector2D(y, -x); }
	
	public double mag(){ return Math.sqrt((x*x)+(y*y)); }
	
	public static double cross(Vector2D u, Vector2D v){ return u.x*v.y-u.y*v.x; }
	public static double dot(Vector2D u, Vector2D v){ return u.x*v.x + u.y*v.y; }

	// Projects the point in this vector's direction for distance d
	public Point2D.Double project(double x, double y, double d){ return project(new Point2D.Double(x,y), d); }
	public Point2D.Double project(Point2D.Double p, double d){
		double m = Math.sqrt((x*x)+(y*y)); // Magnitude
		if(m == 0) return new Point2D.Double(p.x, p.y);
		Point2D.Double q = new Point2D.Double(p.x+(x*d)/m, p.y+(y*d)/m);
		//System.out.println(p+" projected towards "+this+" by "+d+" = "+q);
		return q;
	}
	
	/** Rotates the vector by the given angle */
	public Vector2D rotate(double a){
		return new Vector2D(x*Math.cos(a) - y*Math.sin(a),
		                    x*Math.sin(a) + y*Math.cos(a));
	}
	
	public String toString(){
		return "Vector2D["+x+","+y+"]";
	}

}
